@@ -794,6 +794,7 @@ title_query_tooltip_cb (EditorWindow *self,
                         GtkTooltip   *tooltip)
 {
   g_autofree char *text = NULL;
+  g_autofree char *temp = NULL;
   EditorDocument *document;
   EditorPage *page;
   GFile *file;
@@ -809,7 +810,7 @@ title_query_tooltip_cb (EditorWindow *self,
   if (g_file_is_native (file))
     text = g_file_get_path (file);
   else
-    text = g_file_get_uri (file);
+    text = g_uri_unescape_string ((temp = g_file_get_uri (file)), NULL);
 
   gtk_tooltip_set_text (tooltip, text);
 
@@ -1226,6 +1227,7 @@ buffer_notify_file_cb (EditorDocument *document,
                        AdwTabPage     *tab_page)
 {
   g_autofree char *tooltip = NULL;
+  g_autofree char *escaped = NULL;
   GFile *file;
 
   g_assert (EDITOR_IS_DOCUMENT (document));
@@ -1233,17 +1235,21 @@ buffer_notify_file_cb (EditorDocument *document,
 
   if ((file = editor_document_get_file (document)))
     {
+      g_autofree char *temp = NULL;
+
       if (g_file_is_native (file))
         tooltip = g_file_get_path (file);
       else
-        tooltip = g_file_get_uri (file);
+        tooltip = g_uri_unescape_string ((temp = g_file_get_uri (file)), NULL);
     }
   else
     {
       tooltip = editor_document_dup_title (document);
     }
 
-  adw_tab_page_set_tooltip (tab_page, tooltip);
+  escaped = g_markup_escape_text (tooltip, -1);
+
+  adw_tab_page_set_tooltip (tab_page, escaped);
 }
 
 void
